package App::FileTools::BulkRename;
# ABSTRACT: This will eventually hold the guts of the brn program.
use strict;
use warnings;

BEGIN
  {
    $App::FileTools::BulkRename::VERSION
      = substr '$$Version: 0.03 $$', 11, -3;
  }


1;
